(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23297,        541]*)
(*NotebookOutlinePosition[     24544,        582]*)
(*  CellTagsIndexPosition[     24372,        574]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[" phazeplot", "Title"],

Cell[TextData[{
  "Filename:\tphazeplot.nb\nDescription:\tsome functions for plotting phase \
portraits in  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "\nCreated :\t2005-05-27\n",
  StyleBox["Copyright 2005 California Institute of Technology \n \nThis \
library is free software; you can redistribute it and/or modify it under the \
terms of the GNU Lesser General Public License as published by the Free \
Software Foundation; either version 2.1 of the License, or any later version.\
\n\nThis library is distributed in the hope that it will be useful, but \
WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF MERCHANTABILITY OR \
FITNESS FOR A PARTICULAR PURPOSE.  The software and  documentation provided \
hereunder is on an \"as is\" basis, and the  California Institute of \
Technology has no obligations to provide maintenance, support, updates, \
enhancements or modifications.  In no event shall the California Institute of \
Technology  be liable to any party for direct, indirect, special, incidental \
or consequential damages, including lost profits, arising  out of the use of \
this software and its documentation, even if the California Institute of \
Technology have been advised of the possibility of such damage.  See the GNU \
Lesser General Public License for more details.\n\nYou should have received a \
copy of the GNU Lesser General Public License along with this library; if \
not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, \
Boston, MA 02111-1307 USA.\n\n The original code contained here was initially \
developed by:\n\n \tBruce E. Shapiro\n \tCaltech Systems Biology Group\n \t\
Control and Dynamical Systems, MC 107-81\n \tCalifornia Institute of \
Technology\n \tPasadena, CA, 91125, USA\n \t\n",
    FontSize->12],
  StyleBox["\n",
    FontFamily->"Helvetica",
    FontSize->12],
  StyleBox["\n",
    FontSize->12]
}], "Text"],

Cell[BoxData[{
    \(\(BeginPackage["\<phazeplot`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`PlotField`\>"];\)\), "\[IndentingNewLine]", 
    \(\(Needs["\<Utilities`FilterOptions`\>"];\)\), "\[IndentingNewLine]", 
    \(\(ver = "\<0.1 (27 May 2005)\>";\)\)}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Some documentation",
  FontWeight->"Plain"]], "Section"],

Cell[CellGroupData[{

Cell["?phasePlot", "Subsubsection"],

Cell[BoxData[
    \("phasePlot plots a set of curves in the phase plane\n\
phasePlot[equations, {x,xmin, xmax,xdelta}, {y, ymin, ymax,ydelta},{t, tmin, \
tmax}, options] defines a grid of initial conditions\nphasePlot[equations, \
{x,xmin, xmax}, {y, ymin, ymax},{t, tmin, tmax}, options] defines a grid of \
initial conditions using the value of the option npoints to determine xdelta \
and ydelta.\nphasePlot[equations, {{x1,y1},{x2,y2},...},{t, tmin, tmax}, \
options] defines a list of initial conditions\nAny Graphics option or Plot \
option may be used.\nOther Options:\nfield->False; If true, prints arrows.\n\
npoints->25, size of grid spacing if xdelta and ydelta are not specified. \
"\)], "Print",
  CellTags->"Info3326223614-8234102"]
}, Open  ]],

Cell[CellGroupData[{

Cell["?phazer", "Subsubsection"],

Cell[BoxData[
    \("phazer[equations, {x,xmin,xmax, dx}, {y, ymin,ymax, dy}, {t, \
tmin,tmax}, options] is similar to phasePlot except that the initial \
conditions are only computed along the edge of the box defined by {xmin,xmax} \
by {ymin,ymax} rather than along the entire grid."\)], "Print",
  CellTags->"Info3326223618-6473352"]
}, Open  ]],

Cell[CellGroupData[{

Cell["?parametricVectorPlot", "Subsubsection"],

Cell[BoxData[
    \("parametricVectorPlot[equations,{x,y}, t, \
{xmin,xmax},{ymin,ymax},options] plots the vector field representing the \
phase portrait.\nx,y, and t are the names of the x,y, and t variables in \
equations.\n{xmin,xmax},{ymin,ymax} define a grid for the arrows.\nOptions:\n\
narrows->5, grid spacing for arrows."\)], "Print",
  CellTags->"Info3326223624-5067863"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Declare Entry Points",
  FontWeight->"Plain"]], "Section"],

Cell[BoxData[{
    \(\(phasePlot::usage = "\<phasePlot plots a set of curves in the phase \
plane\n\>" <> "\<phasePlot[equations, {x,xmin, xmax,xdelta}, {y, ymin, \
ymax,ydelta},{t, tmin, tmax}, options] defines a grid of initial conditions\n\
\>" <> \[IndentingNewLine]"\<phasePlot[equations, {x,xmin, xmax}, {y, ymin, \
ymax},{t, tmin, tmax}, options] defines a grid of initial conditions using \
the value of the option npoints to determine xdelta and ydelta.\n\>" \
<> \[IndentingNewLine]"\<phasePlot[equations, {{x1,y1},{x2,y2},...},{t, tmin, \
tmax}, options] defines a list of initial conditions\nAny Graphics option or \
Plot option may be used.\nOther Options:\nfield->False; If true, prints \
arrows.\nnpoints->25, size of grid spacing if xdelta and ydelta are not \
specified. \>";\)\), "\[IndentingNewLine]", 
    \(\(parametricVectorPlot::usage = \
"\<parametricVectorPlot[equations,{x,y}, t, {xmin,xmax},{ymin,ymax},options] \
plots the vector field representing the phase portrait.\nx,y, and t are the \
names of the x,y, and t variables in equations.\n{xmin,xmax},{ymin,ymax} \
define a grid for the arrows.\nOptions:\nnarrows->5, grid spacing for arrows.\
\>";\)\), "\[IndentingNewLine]", 
    \(\(parametricPlotVar::usage = "\<\>";\)\), "\[IndentingNewLine]", 
    \(\(plotVar::usage = "\<\>";\)\), "\[IndentingNewLine]", 
    \(\(edgePoints::usage = "\<\>";\)\), "\[IndentingNewLine]", 
    \(\(Options[phasePlot] = {npoints \[Rule] \ 25, 
          field \[Rule] \ False};\)\), "\[IndentingNewLine]", 
    \(\(npoints::usage = "\<\>";\)\), "\[IndentingNewLine]", 
    \(\(field::usage = "\<field is an option for phasePlot\>";\)\), "\
\[IndentingNewLine]", 
    \(\(phazer::usage = "\<phazer[equations, {x,xmin,xmax, dx}, {y, \
ymin,ymax, dy}, {t, tmin,tmax}, options] is similar to phasePlot except that \
the initial conditions are only computed along the edge of the box defined by \
{xmin,xmax} by {ymin,ymax} rather than along the entire grid.\>";\)\), "\
\[IndentingNewLine]", 
    \(\(narrows::usage = "\<narrows is an option for \
parametricVectorPlot.\>";\)\), "\[IndentingNewLine]", 
    \(eigenplot::usage = "\<eigenplot[A,len,{gdir},options] plots the \
eigenvectors of the matrix A. The vectors are normalized to length len.\ngdir \
is a sequence of graphics directives to be applied to the arrow, such as \
Thickness or Hue.\nAny valid option to Graphis or Graphics`Arrow may be used.\
\>"\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[BoxData[
    \(\(\(Begin["\<`Private`\>"];\)\(\ \ \)\)\)], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["plotVar, parametricPlotVar\n",
    FontWeight->"Plain"],
  StyleBox["plot a variable against a numerical (NDSolve) solution\n\
parametric plot two variables against each other",
    FontSize->15,
    FontWeight->"Plain"]
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["plotVar[x, n, tfrom, tto, options] ",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox["plots the variable in the evaluated solution over the specified \
time range\n",
    FontSize->14],
  StyleBox["plotVar[x, n, options]",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox[" plots the entire range of the numerical solution by \
automatically figuring out what it is\n\n",
    FontSize->14],
  StyleBox["plotVarList[n, vlist, options]",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox[" plots a list of variables on separate plots\n",
    FontSize->14],
  StyleBox["plotVarList[n, tfrom, tto, options]\n\nparametricPlotVar[n, \
{x,y},{t,tfrom,tto},options]\nparametricPlotVar[n, {x,y}, t, options]\n\
parametricPlotVar[n, {x,y}, options]\nparametricPlotVar[n, {x,y}]",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox["\n\n",
    FontSize->14],
  StyleBox["timeRange[n]",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox[" figures out what the time range of a numerical solution is\n\n\
The format of ",
    FontSize->14],
  StyleBox["n",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox[" must be like the following example: \n",
    FontSize->14],
  StyleBox["{{a[1][t]\[Rule]InterpolatingFunction[{{0.,100.}},<>][t],\n    \
a[2][t]\[Rule]InterpolatingFunction[{{0.,100.}},<>][t],  ...\n    y[2][t]\
\[Rule]InterpolatingFunction[{{0.,100.}},<>][t],\n    \
z[1][t]\[Rule]InterpolatingFunction[{{0.,100.}},<>][t],\n    \
z[2][t]\[Rule]InterpolatingFunction[{{0.,100.}},<>][t]}}",
    FontFamily->"Courier",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox["\n\n",
    FontSize->14]
}], "Text"],

Cell[BoxData[
    \(\(timeRange[
          n_] := \ \(Head[n[\([1, 1, 2]\)]]\)[\([1, 1]\)];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(plotVar[x_, n_, opt___?OptionQ] := \ 
      Module[{tfrom, tto}, \[IndentingNewLine]{tfrom, tto} = 
          timeRange[n]; \[IndentingNewLine]plotVar[x, n, tfrom, tto, 
          opt]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(plotVar[x_, n_, tfrom_, \ tto_, opt___?OptionQ] := \ 
        Module[{popt}, \[IndentingNewLine]Return[
            Plot[Evaluate[x[t] /. n], {t, tfrom, \ tto}, 
              FilterOptions[Plot, opt], \ 
              PlotLabel \[Rule] \ ToString[x]]]];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(plotVarList[n_, \ tfrom_, \ tto_, vlist_?ListQ, opt___?OptionQ] := 
        Map[plotVar[#, n, tfrom, tto, opt] &, 
          vlist];\)\), "\[IndentingNewLine]", 
    \(\(plotVarList[n_, \ vlist_?ListQ, opt___?OptionQ] := 
        Map[plotVar[#, n, opt] &, vlist];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(parametricPlotVar[n_, {x_, y_}, {t_, tfrom_, \ tto_}, 
          opt___?OptionQ] := \ \
\[IndentingNewLine]\[IndentingNewLine]Module[{popt, 
            args}, \[IndentingNewLine]popt = 
            Utilities`FilterOptions`FilterOptions[Plot, 
              opt]; \[IndentingNewLine]args = {Evaluate[{x[t], y[t]} /. 
                  n], {t, tfrom, 
                tto}, \[IndentingNewLine]popt}; \[IndentingNewLine]Return[
            ParametricPlot @@ 
              args\[IndentingNewLine]]];\)\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(parametricPlotVar[n_, {x_, y_}, t, opt___?OptionQ] := \ 
        Module[{tfrom, tto}, {tfrom, tto} = 
            timeRange[n]; \[IndentingNewLine]parametricPlotVar[
            n, {x, y}, {t, tfrom, tto}, opt]];\)\), "\[IndentingNewLine]", 
    \(\(parametricPlotVar[n_, {x_, y_}, opt___?OptionQ] := \ 
        Module[{tfrom, tto, tvariable}, {tfrom, tto} = 
            timeRange[n]; \[IndentingNewLine]tvariable = 
            n[\([1, 1, 2, 1]\)]; \[IndentingNewLine]parametricPlotVar[
            n, {x, y}, {tvariable, tfrom, tto}, opt]];\)\)}], "Input",
  InitializationCell->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["parametricVectorPlot\n",
    FontWeight->"Plain"],
  StyleBox["plot a vector field from a parameterized set of equations",
    FontSize->15,
    FontWeight->"Plain"]
}], "Section"],

Cell[BoxData[
    \(\(parametricVectorPlot[eqs_, {x_, y_}, \ t_, \ xrange_, yrange_, 
          opt___?OptionQ] := \ 
        Module[{rhs, vecs, xmin, xmax, ymin, ymax, ix, iy, lengthlist, 
            vecvals, veclocs, nlen, vecplot, 
            nvecs}, \[IndentingNewLine]\[IndentingNewLine]nvecs = \(narrows /. \
{opt}\) /. {narrows \[Rule] \ 
                  5}; \[IndentingNewLine]\[IndentingNewLine]rhs\  = \ 
            Map[Last, eqs] /. {x[t] \[Rule] \ ix, 
                y[t] \[Rule] \ iy}; \[IndentingNewLine]{xmin, xmax} = 
            xrange; \[IndentingNewLine]{ymin, ymax} = 
            yrange; \[IndentingNewLine]vecs = 
            Flatten[Table[{{ix, iy}, rhs}, {ix, xmin, 
                  xmax, \((xmax - xmin)\)/nvecs}, {iy, ymin, 
                  ymax, \((ymax - ymin)\)/nvecs}], 
              1]; \[IndentingNewLine]tvecs = 
            Transpose[vecs]; \[IndentingNewLine]{veclocs, vecvals} = 
            tvecs; \[IndentingNewLine]lengthlist = 
            Map[Sqrt[Last[#] . Last[#]] &, vecs]; \[IndentingNewLine]For[
            i = 1, i \[LessEqual] \ 
              Length[lengthlist], \(i++\), \[IndentingNewLine]\ \(If[
                lengthlist[\([i]\)] \[Equal] 0, \ 
                lengthlist\  = \ 
                  ReplacePart[lengthlist, 1, 
                    i]];\)\[IndentingNewLine]]; \[IndentingNewLine]vecvals\  \
= \ vecvals/lengthlist; \[IndentingNewLine]nlen\  = \ 
            Sqrt[\((xmax - xmin)\)^2 + \((ymax - ymin)\)^2]/
              25; \[IndentingNewLine]vecvals\  = \ 
            vecvals*nlen; \[IndentingNewLine]vecs\  = \ 
            Transpose[{veclocs, \ vecvals}]; \[IndentingNewLine]vecplot = 
            ListPlotVectorField[vecs, opt]\[IndentingNewLine]];\)\)], "Input",\

  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["phasePlot",
  FontWeight->"Plain"]], "Section",
  CellFrame->{{0, 0}, {0, 3}}],

Cell[CellGroupData[{

Cell["edgePoints", "Subsection"],

Cell[BoxData[
    \(\(\(edgePoints[{xmin_, xmax_, dx_}, \ {ymin_, ymax_, dy_}] := \ 
      Module[{top, bottom, \ left, \ right, v, xl, xr, yb, 
          yt}, \[IndentingNewLine]xl\  = \ 
          Min[xmin, xmax]; \[IndentingNewLine]xr\  = \ 
          Max[xmin, xmax]; \[IndentingNewLine]yt = 
          Max[ymin, ymax]; \[IndentingNewLine]yb = 
          Min[ymin, ymax]; \[IndentingNewLine]\[IndentingNewLine]top\  = \ 
          Table[{v, yt}, \ {v, xl, xr, dx}]; \[IndentingNewLine]bottom = 
          Table[{v, yb}, \ {v, xl, xr, dx}]; \[IndentingNewLine]left = 
          Table[{xl, \ v}, \ {v, yb + dy, yt - dy, \ 
              dy}]; \[IndentingNewLine]right = 
          Table[{xr, \ v}, \ {v, yb + dy, yt - dy, 
              dy}]; \[IndentingNewLine]\[IndentingNewLine]Return[
          Join[top, bottom, left, 
            right]]\[IndentingNewLine]\[IndentingNewLine]]\)\(\
\[IndentingNewLine]\)
    \)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["phasePlot ", "Subsection"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)\(\(phasePlot[
          eq_, \ {x_, xmin_, \ xmax_, xdelta_}, \ {y_, \ ymin_, \ ymax_, 
            ydelta_}, {t_, \ tmin_, \ tmax_}, \ opt___?OptionQ] := \ 
        Module[{\ ix, \ iy, ic, n, vars, p, plist = {}, npts, plotfield, vp, 
            gopt, nopt}, \[IndentingNewLine]\[IndentingNewLine]gopt\  = \ 
            FilterOptions[Graphics, opt]; \[IndentingNewLine]nopt = \ 
            FilterOptions[NDSolve, 
              opt]; \[IndentingNewLine]\[IndentingNewLine]vars = {x[t], 
              y[t]}; \[IndentingNewLine]For[ix = xmin, \ 
            ix \[LessEqual] \ xmax, \ 
            ix += \ xdelta, \ \[IndentingNewLine]For[iy = ymin, \ 
              iy \[LessEqual] \ ymax, \ 
              iy += \ ydelta, \ \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]ic = {x[tmin] \[Equal] \ ix, \ 
                  y[tmin] \[Equal] \ 
                    iy}; \[IndentingNewLine]\[IndentingNewLine]n = 
                NDSolve[Join[eq, ic], vars, {t, tmin, tmax}, 
                  nopt]; \[IndentingNewLine]p = 
                parametricPlotVar[n, {x, y}, {t, tmin, tmax}, opt, 
                  PlotRange \[Rule] \ All, \ 
                  DisplayFunction \[Rule] \ 
                    Identity]; \[IndentingNewLine]plist\  = \ 
                Append[plist, 
                  p];\[IndentingNewLine]\[IndentingNewLine]]\
\[IndentingNewLine]]; \[IndentingNewLine]plotfield\  = \ \(field /. {opt}\) /. 
              Options[phasePlot]; \[IndentingNewLine]If[
            plotfield, \ \[IndentingNewLine]vp = 
              parametricVectorPlot[eq, {x, y}, t, {xmin, xmax}, {ymin, ymax}, 
                opt, DisplayFunction \[Rule] \ 
                  Identity]; \[IndentingNewLine]Return[
              Show[plist, vp, gopt, \ 
                DisplayFunction \[Rule] \ $DisplayFunction, \ 
                PlotRange \[Rule] \ 
                  All]]\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]Show[plist, gopt, 
            DisplayFunction \[Rule] \ $DisplayFunction, \ 
            PlotRange \[Rule] \ 
              All]\[IndentingNewLine]];\)\[IndentingNewLine]
    \(phasePlot[
          eq_, \ {x_, xmin_, \ xmax_}, \ {y_, \ ymin_, \ ymax_}, {t_, \ 
            tmin_, \ tmax_}, \ opt___?OptionQ] := \ 
        Module[{nx, ny, np, xdelta, 
            ydelta}, \[IndentingNewLine]np\  = \ \(npoints /. {opt}\) /. 
              Options[phasePlot]; \[IndentingNewLine]\[IndentingNewLine]nx\  \
= \ Ceiling[\@np]; \[IndentingNewLine]ny = 
            nx; \[IndentingNewLine]xdelta\  = \ \((xmax - xmin)\)/
              nx; \[IndentingNewLine]ydelta\  = \ \((ymax - ymin)\)/
              ny; \[IndentingNewLine]\[IndentingNewLine]phasePlot[
            eq, \ {x, xmin, \ xmax, xdelta}, \ {y, \ ymin, \ ymax, 
              ydelta}, {t, \ tmin, \ tmax}, \ 
            opt]\[IndentingNewLine]];\)\[IndentingNewLine]\[IndentingNewLine]
    \(phasePlot[eq_, \ {pt__?ListQ}, {x_, y_}, \ {t_, \ tmin_, \ tmax_}, \ 
          opt___?OptionQ] := \ 
        Module[{\ ix, \ iy, ic, n, vars, p, plist = {}, npts, plotfield, vp, 
            gopt, \ pts, \ 
            nopt}, \[IndentingNewLine]\[IndentingNewLine]npts = 
            Union[Length /@ {pt}]; \[IndentingNewLine]If[
            Length[Complement[npts, {2}]] > 
              0, \ \[IndentingNewLine]Print["\<Invalid list of points, \>", \ \
{pt}]; \[IndentingNewLine]Abort[];\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]gopt\  = \ 
            FilterOptions[Graphics, opt]; \[IndentingNewLine]nopt = \ 
            FilterOptions[NDSolve, 
              opt]; \[IndentingNewLine]\[IndentingNewLine]vars = {x[t], 
              y[t]}; \[IndentingNewLine]pts = {pt}; \[IndentingNewLine]While[
            Length[pts] > 0, \ \[IndentingNewLine]{ix, iy} = 
              First[pts]; \[IndentingNewLine]pts = 
              Rest[pts]; \[IndentingNewLine]\[IndentingNewLine]ic = {x[
                    tmin] \[Equal] \ ix, \ 
                y[tmin] \[Equal] \ 
                  iy}; \[IndentingNewLine]\[IndentingNewLine]n = 
              NDSolve[Join[eq, ic], vars, {t, tmin, tmax}, 
                nopt]; \[IndentingNewLine]\[IndentingNewLine]p = 
              parametricPlotVar[n, {x, y}, {t, tmin, tmax}, opt, 
                PlotRange \[Rule] \ All, \ 
                DisplayFunction \[Rule] \ 
                  Identity]; \[IndentingNewLine]plist\  = \ 
              Append[plist, 
                p];\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]];\
 \[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]Show[plist, gopt, 
            DisplayFunction \[Rule] \ $DisplayFunction, \ 
            PlotRange \[Rule] \ 
              All]\[IndentingNewLine]];\)\[IndentingNewLine]\
\[IndentingNewLine]
    \)\)\)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["phazer",
  FontWeight->"Plain"]], "Section"],

Cell[BoxData[
    \(phazer[
        eq_, \ {x_, xmin_, xmax_, \ dx_}, \ {y_, \ ymin_, ymax_, \ 
          dy_}, \ {t_, \ tmin_, tmax_}, \ opt___?OptionQ] := \ 
      Module[{p1, p2, edge, gopt}, \[IndentingNewLine]edge = 
          edgePoints[{xmin, xmax, dx}, \ {ymin, ymax, 
              dy}]; \[IndentingNewLine]p1 = 
          phasePlot[eq, edge, {x, y}, {t, tmin, tmax}, 
            DisplayFunction \[Rule] \ Identity, 
            opt]; \[IndentingNewLine]gopt = 
          FilterOptions[Graphics, opt]; \[IndentingNewLine]If[
          field /. {opt}, \[IndentingNewLine]p2 = 
            parametricVectorPlot[eq, \ {x, y}, 
              t, {xmin, xmax}, {ymin, ymax}, \ 
              DisplayFunction \[Rule] \ Identity, \ opt, 
              PlotRange \[Rule] \ {{xmin, xmax}, {ymin, 
                    ymax}}\[IndentingNewLine]]; \[IndentingNewLine]Return[
            Show[{p1, p2}, \ gopt, \ 
              DisplayFunction \[Rule] \ \
$DisplayFunction]];\[IndentingNewLine]]; \[IndentingNewLine]Return[
          Show[p1, gopt, 
            DisplayFunction \[Rule] \ $DisplayFunction]];\[IndentingNewLine]]\
\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["eigenplot",
  FontWeight->"Plain"]], "Section"],

Cell[BoxData[
    \(eigenplot[M_, \ l_, {gdir___}, opt___?OptionQ] := \ 
      Module[{v1, v2, aopt, gopt, g}, \[IndentingNewLine]aopt = 
          FilterOptions[Arrow, opt]; \[IndentingNewLine]{v1, v2} = 
          Eigenvectors[M]; \[IndentingNewLine]{v1, v2} = 
          Map[l*#/\@\(# . #\) &, {v1, v2}]; \[IndentingNewLine]{v1, 
            v2} = \(Arrow[{0, 0}, #, aopt] &\) /@ {v1, 
              v2}; \[IndentingNewLine]gopt = 
          FilterOptions[Graphics, 
            opt]; \[IndentingNewLine]Show[{\(Graphics[{gdir, #}] &\) /@ {v1, 
                  v2}} // Flatten, gopt]\[IndentingNewLine]]\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[BoxData[{
    \(\(Print["\<phazeplot \>", 
        ver, "\< loaded.\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(End[];\)\), "\[IndentingNewLine]", 
    \(\(EndPackage[];\)\)}], "Input",
  InitializationCell->True]
},
FrontEndVersion->"5.1 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 828}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{702, 610},
WindowMargins->{{Automatic, 219}, {75, Automatic}},
ShowSelection->True,
Magnification->1.25,
StyleDefinitions -> "xlr8r-style.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Info3326223614-8234102"->{
    Cell[4180, 104, 746, 11, 266, "Print",
      CellTags->"Info3326223614-8234102"]},
  "Info3326223618-6473352"->{
    Cell[4998, 122, 336, 5, 106, "Print",
      CellTags->"Info3326223618-6473352"]},
  "Info3326223624-5067863"->{
    Cell[5420, 134, 381, 6, 146, "Print",
      CellTags->"Info3326223624-5067863"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Info3326223614-8234102", 24028, 561},
  {"Info3326223618-6473352", 24145, 564},
  {"Info3326223624-5067863", 24261, 567}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 27, 0, 112, "Title"],
Cell[1784, 53, 1912, 33, 792, "Text"],
Cell[3699, 88, 313, 5, 100, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4037, 97, 80, 1, 78, "Section"],

Cell[CellGroupData[{
Cell[4142, 102, 35, 0, 63, "Subsubsection"],
Cell[4180, 104, 746, 11, 266, "Print",
  CellTags->"Info3326223614-8234102"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4963, 120, 32, 0, 63, "Subsubsection"],
Cell[4998, 122, 336, 5, 106, "Print",
  CellTags->"Info3326223618-6473352"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5371, 132, 46, 0, 63, "Subsubsection"],
Cell[5420, 134, 381, 6, 146, "Print",
  CellTags->"Info3326223624-5067863"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[5850, 146, 82, 1, 57, "Section"],
Cell[5935, 149, 2465, 38, 764, "Input",
  InitializationCell->True]
}, Closed]],
Cell[8415, 190, 100, 2, 42, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[8540, 196, 263, 7, 124, "Section"],

Cell[CellGroupData[{
Cell[8828, 207, 1820, 52, 615, "Text"],
Cell[10651, 261, 134, 3, 44, "Input",
  InitializationCell->True],
Cell[10788, 266, 265, 5, 104, "Input",
  InitializationCell->True],
Cell[11056, 273, 319, 6, 104, "Input",
  InitializationCell->True],
Cell[11378, 281, 330, 6, 104, "Input",
  InitializationCell->True],
Cell[11711, 289, 1166, 21, 344, "Input",
  InitializationCell->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[12926, 316, 208, 6, 80, "Section"],
Cell[13137, 324, 1779, 32, 484, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[14953, 361, 102, 2, 57, "Section"],

Cell[CellGroupData[{
Cell[15080, 367, 32, 0, 70, "Subsection"],
Cell[15115, 369, 959, 18, 344, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[16111, 392, 32, 0, 53, "Subsection"],
Cell[16146, 394, 4868, 86, 1663, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[21063, 486, 68, 1, 57, "Section"],
Cell[21134, 489, 1166, 23, 324, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[22337, 517, 71, 1, 57, "Section"],
Cell[22411, 520, 649, 11, 221, "Input",
  InitializationCell->True]
}, Closed]],
Cell[23075, 534, 218, 5, 80, "Input",
  InitializationCell->True]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

