(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     40932,       1394]*)
(*NotebookOutlinePosition[     41494,       1414]*)
(*  CellTagsIndexPosition[     41450,       1410]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default \
appearance of all cells in a given style. Make modifications to any \
definition using commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  CellBracketOptions->{
  "Color"->RGBColor[0.771908, 0.399634, 0.262867]},
  ScriptMinSize->9],

Cell[StyleData[All, "Presentation"],
  CellBracketOptions->{
  "Color"->RGBColor[0.771908, 0.399634, 0.262867]},
  ScriptMinSize->9],

Cell[StyleData[All, "SlideShow"],
  PageWidth->WindowWidth,
  ScrollingOptions->{"PagewiseDisplay"->True,
  "VerticalScrollRange"->Fit},
  ShowCellBracket->False,
  CellBracketOptions->{
  "Color"->RGBColor[0.771908, 0.399634, 0.262867]},
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  PrivateFontOptions->{"FontType"->"Outline"}],

Cell[StyleData[All, "ColorPrintout"],
  PageWidth->PaperWidth,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  StyleMenuListing->None],

Cell[StyleData["Notebook", "Presentation"],
  FontSize->18]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellMargins->{{36, 20}, {2, 10}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakBelow->False,
  CellFrameMargins->{{100, 4}, {8, 10}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
      "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
          TextForm], Inherited},
  TextAlignment->Left,
  LineSpacing->{1, 17},
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}},
  FontSize->60,
  FontSlant->"Italic",
  FontColor->RGBColor[0.620523, 0.66688, 0.409964]],

Cell[StyleData["Title", "Presentation"],
  CellMargins->{{56, 20}, {8, 18}},
  FontSize->90],

Cell[StyleData["Title", "Printout"],
  FontSize->48,
  FontColor->GrayLevel[0.4]],

Cell[StyleData["Title", "ColorPrintout"],
  FontSize->48]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{144, 20}, {2, 10}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
      "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
          TextForm], Inherited},
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subsubtitle", 0}},
  FontSize->24,
  FontSlant->"Italic",
  FontColor->RGBColor[0.326787, 0.658763, 0.400732]],

Cell[StyleData["Subtitle", "Presentation"],
  CellMargins->{{220, 20}, {2, 16}},
  FontSize->36],

Cell[StyleData["Subtitle", "Printout"],
  FontSize->18,
  FontColor->GrayLevel[0.300008]],

Cell[StyleData["Subtitle", "ColorPrintout"],
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{144, 20}, {2, 2}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
      "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
          TextForm], Inherited},
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontSlant->"Italic"],

Cell[StyleData["Subsubtitle", "Presentation"],
  CellMargins->{{220, 20}, {4, 4}},
  FontSize->21],

Cell[StyleData["Subsubtitle", "Printout"],
  FontSize->12],

Cell[StyleData["Subsubtitle", "ColorPrintout"],
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellFrame->{{0, 0}, {0, 3}},
  CellMargins->{{36, 20}, {10, 20}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameMargins->{{10, 4}, {6, 2}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
      "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
          TextForm], Inherited},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Arial",
  FontSize->24,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["Section", "Presentation"],
  CellMargins->{{56, 20}, {16, 26}},
  FontSize->21],

Cell[StyleData["Section", "Printout"],
  FontSize->14,
  FontColor->GrayLevel[0.300008]],

Cell[StyleData["Section", "ColorPrintout"],
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellFrame->{{0, 0}, {0, 0.5}},
  CellDingbat->"\[GraySquare]",
  CellMargins->{{53, 20}, {Inherited, 18}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CellFrameMargins->{{2, 12}, {0, 12}},
  CellFrameLabelMargins->6,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
      "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
          TextForm], Inherited},
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Arial",
  FontSize->18,
  FontWeight->"Bold",
  FontColor->RGBColor[0.749996, 0, 0.749996],
  Background->RGBColor[0.749996, 1, 0.749996]],

Cell[StyleData["Subsection", "Presentation"],
  CellMargins->{{56, 20}, {10, 28}},
  FontSize->18],

Cell[StyleData["Subsection", "Printout"]],

Cell[StyleData["Subsection", "ColorPrintout"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellFrame->{{0, 0}, {0, 0.5}},
  CellDingbat->None,
  CellMargins->{{51, Inherited}, {Inherited, 12}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CellFrameLabelMargins->6,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
      "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
          TextForm], Inherited},
  CounterIncrements->"Subsubsection",
  FontFamily->"Arial",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0.228321, 0.223514, 0.570138],
  Background->RGBColor[1, 0.874372, 0.698604],
  FontVariations->{"Outline"->False,
  "Shadow"->False}],

Cell[StyleData["Subsubsection", "Presentation"],
  CellMargins->{{56, 20}, {6, 14}},
  FontSize->15],

Cell[StyleData["Subsubsection", "Printout"]],

Cell[StyleData["Subsubsection", "ColorPrintout"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellFrame->False,
  CellMargins->{{36, 20}, {4, 4}},
  CellFrameMargins->{{4, 10}, {6, 0}},
  CellFrameLabelMargins->4,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
      "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
          TextForm], Inherited},
  LineSpacing->{1, 6},
  CounterIncrements->"Text"],

Cell[StyleData["Text", "Presentation"],
  CellMargins->{{56, 20}, {8, 6}},
  FontSize->18],

Cell[StyleData["Text", "Printout"],
  Hyphenation->True,
  LineSpacing->{1, 5},
  FontSize->10],

Cell[StyleData["Text", "ColorPrintout"],
  Hyphenation->True,
  LineSpacing->{1, 5},
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{100, 38}, {4, 4}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
      "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
          TextForm], Inherited},
  LineSpacing->{1.25, 1},
  CounterIncrements->"SmallText",
  FontSize->10],

Cell[StyleData["SmallText", "Presentation"],
  CellMargins->{{152, 38}, {6, 6}},
  FontSize->15],

Cell[StyleData["SmallText", "Printout"],
  Hyphenation->True,
  FontSize->9],

Cell[StyleData["SmallText", "ColorPrintout"],
  Hyphenation->True,
  FontSize->9]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inline Formatting", "Section"],

Cell["\<\
These styles are for modifying individual words or letters \
in a cell exclusive of the cell tag.\
\>", "Text"],

Cell[StyleData["RM"],
  StyleMenuListing->None,
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["BF"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["IT"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["TR"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["TI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["TB"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["TBI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["MR"],
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["MO"],
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["MB"],
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["MBO"],
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["SR"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["SO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SB"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["SBO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[StyleData["SO10"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SO10", "Printout"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->7,
  FontWeight->"Plain",
  FontSlant->"Italic"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Inert"],
  StyleMenuListing->None,
  Background->RGBColor[0.870588, 0.905882, 0.972549]],

Cell[StyleData["Inert", "Printout"],
  StyleMenuListing->None,
  Background->GrayLevel[1]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and \
output to the kernel.  Be careful when modifying, renaming, or \
removing these styles, because the front end associates special \
meanings with these style names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellFrame->True,
  CellMargins->{{36, 0}, {0, Inherited}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultInputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->RGBColor[0.840558, 0.58323, 0.941176]],

Cell[StyleData["Input", "Presentation"],
  CellMargins->{{56, 0}, {0, 8}},
  CellFrameMargins->{{10, 10}, {12, 12}},
  FontSize->18],

Cell[StyleData["Input", "Printout"],
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["Input", "ColorPrintout"],
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  FontSize->10]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["InlineInput"],
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  FontWeight->"Bold"],

Cell[StyleData["InlineInput", "Presentation"],
  CellMargins->{{10, 4}, {6, 6}},
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{36, 0}, {Inherited, 0}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  CounterIncrements->"Output",
  FontColor->GrayLevel[0],
  Background->RGBColor[0.620523, 0.66688, 0.409964]],

Cell[StyleData["Output", "Presentation"],
  CellMargins->{{56, 0}, {8, 0}},
  CellFrameMargins->{{12, 10}, {12, 12}},
  FontSize->18],

Cell[StyleData["Output", "Printout"],
  FontSize->10,
  Background->GrayLevel[0.8]],

Cell[StyleData["Output", "ColorPrintout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellDingbat->"\[LongDash]",
  CellMargins->{{64, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  AutoStyleOptions->{"UnmatchedBracketStyle"->None},
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontSlant->"Oblique"],

Cell[StyleData["Message", "Presentation"],
  CellMargins->{{96, 10}, {8, 6}},
  FontSize->15],

Cell[StyleData["Message", "Printout"],
  FontSize->8],

Cell[StyleData["Message", "ColorPrintout"],
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  CellMargins->{{36, 20}, {3, 3}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{3, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  "TwoByteSyntaxCharacterAutoReplacement"->True,
  TextAlignment->Left,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None,
  Background->RGBColor[0.967727, 0.972747, 0.534508]],

Cell[StyleData["Print", "Presentation"],
  CellMargins->{{56, 20}, {2, 2}},
  CellFrameMargins->{{10, 10}, {12, 12}},
  FontSize->18],

Cell[StyleData["Print", "Printout"],
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["Print", "ColorPrintout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{36, 0}, {0, 0}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  ImageMargins->{{35, Inherited}, {Inherited, 0}},
  Background->RGBColor[0.901915, 0.799634, 0.502861]],

Cell[StyleData["Graphics", "Presentation"],
  CellMargins->{{56, 20}, {0, 2}},
  CellFrameMargins->{{10, 10}, {12, 12}},
  FontSize->18],

Cell[StyleData["Graphics", "Printout"],
  FontSize->10,
  Background->GrayLevel[0.8]],

Cell[StyleData["Graphics", "ColorPrintout"],
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontColor->RGBColor[0.551492, 0.231144, 0.313466]],

Cell[StyleData["CellLabel", "Presentation"],
  FontSize->14],

Cell[StyleData["CellLabel", "Printout"],
  FontSize->8,
  FontColor->GrayLevel[0]],

Cell[StyleData["CellLabel", "ColorPrintout"],
  FontSize->8]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same \
Notebook, or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0.269993, 0.308507, 0.6],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonFrame->"None",
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Presentation"],
  FontSize->16],

Cell[StyleData["Hyperlink", "Condensed"],
  FontSize->11],

Cell[StyleData["Hyperlink", "SlideShow"]],

Cell[StyleData["Hyperlink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the \
on-line help system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0.269993, 0.308507, 0.6],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Presentation"],
  FontSize->16],

Cell[StyleData["MainBookLink", "Condensed"],
  FontSize->11],

Cell[StyleData["MainBookLink", "SlideShow"]],

Cell[StyleData["MainBookLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0.269993, 0.308507, 0.6],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnsLink", "Presentation"],
  FontSize->16],

Cell[StyleData["AddOnsLink", "Condensed"],
  FontSize->11],

Cell[StyleData["AddOnsLink", "SlideShow"]],

Cell[StyleData["AddOnsLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0.269993, 0.308507, 0.6],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Presentation"],
  FontSize->16],

Cell[StyleData["RefGuideLink", "Condensed"],
  FontSize->11],

Cell[StyleData["RefGuideLink", "SlideShow"]],

Cell[StyleData["RefGuideLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLinkText"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0.269993, 0.308507, 0.6],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLinkText", "Presentation"],
  FontSize->16],

Cell[StyleData["RefGuideLinkText", "Condensed"],
  FontSize->11],

Cell[StyleData["RefGuideLinkText", "SlideShow"]],

Cell[StyleData["RefGuideLinkText", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0.269993, 0.308507, 0.6],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Presentation"],
  FontSize->16],

Cell[StyleData["GettingStartedLink", "Condensed"],
  FontSize->11],

Cell[StyleData["GettingStartedLink", "SlideShow"]],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DemosLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0.269993, 0.308507, 0.6],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "Demos", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["DemosLink", "SlideShow"]],

Cell[StyleData["DemosLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TourLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0.269993, 0.308507, 0.6],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "Tour", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["TourLink", "SlideShow"]],

Cell[StyleData["TourLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0.269993, 0.308507, 0.6],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Presentation"],
  FontSize->16],

Cell[StyleData["OtherInformationLink", "Condensed"],
  FontSize->11],

Cell[StyleData["OtherInformationLink", "SlideShow"]],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MasterIndexLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0.269993, 0.308507, 0.6],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MasterIndexLink", "SlideShow"]],

Cell[StyleData["MasterIndexLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Slide Show Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["SlideShowNavigationBar"],
  Editable->False,
  CellFrame->True,
  CellMargins->{{0, 0}, {3, 3}},
  CellElementSpacings->{"CellMinHeight"->0.8125},
  CellGroupingRules->{"SectionGrouping", 30},
  CellFrameMargins->False,
  CellFrameColor->GrayLevel[1],
  CellFrameLabelMargins->False,
  TextAlignment->Center,
  CounterIncrements->"SlideShowNavigationBar",
  StyleMenuListing->None,
  FontSize->10,
  Background->GrayLevel[0.8],
  Magnification->1,
  GridBoxOptions->{GridBaseline->Center,
  RowSpacings->0,
  ColumnSpacings->0,
  ColumnWidths->{3.5, 3.5, 3.5, 3.5, 13, 5, 4},
  RowAlignments->Baseline,
  ColumnAlignments->{
    Center, Center, Center, Center, Center, Center, Right, Center}}],

Cell[StyleData["SlideShowNavigationBar", "SlideShow"],
  Deletable->False,
  ShowCellBracket->False,
  CellMargins->{{-1, -1}, {-1, -1}},
  PageBreakAbove->True,
  CellFrameMargins->{{1, 1}, {0, 0}}],

Cell[StyleData["SlideShowNavigationBar", "Printout"],
  CellMargins->{{18, 4}, {4, 4}},
  LineSpacing->{1, 3},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SlideShowSection"],
  CellFrame->{{0, 0}, {0, 0.5}},
  CellMargins->{{0, 0}, {10, 0}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CellFrameMargins->{{12, 4}, {6, 12}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, 
                BoxBaselineShift -> -0.20000000000000001], FontSize -> 
              Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
      "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", "gridMathematica"->FormBox[ 
          RowBox[ {"grid", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], 
      "webMathematica"->FormBox[ 
          RowBox[ {"web", 
            AdjustmentBox[ 
              StyleBox[ "Mathematica", FontSlant -> "Italic"], 
              BoxMargins -> {{-0.17499999999999999, 0}, {0, 0}}]}], 
          TextForm], Inherited},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->18,
  FontWeight->"Plain",
  FontColor->GrayLevel[1],
  Background->RGBColor[0.408011, 0.440726, 0.8]],

Cell[StyleData["SlideShowSection", "Presentation"],
  CellFrameMargins->{{18, 10}, {10, 18}},
  FontSize->27],

Cell[StyleData["SlideShowSection", "SlideShow"],
  ShowCellBracket->False,
  PageBreakAbove->True],

Cell[StyleData["SlideShowSection", "Printout"],
  CellMargins->{{18, 30}, {0, 30}},
  CellFrameMargins->5,
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SlideHyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontSize->26,
  FontColor->GrayLevel[0.400015],
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonMinHeight->0.85,
  ButtonMargins->0.5,
  ButtonNote->None}],

Cell[StyleData["SlideHyperlink", "Presentation"],
  CellMargins->{{10, 10}, {10, 12}},
  FontSize->36],

Cell[StyleData["SlideHyperlink", "SlideShow"]],

Cell[StyleData["SlideHyperlink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SlideTOCLink"],
  CellMargins->{{24, Inherited}, {Inherited, Inherited}},
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Helvetica",
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonMargins->1.5,
  ButtonNote->ButtonData}],

Cell[StyleData["SlideTOCLink", "Presentation"],
  CellMargins->{{35, 10}, {5, 10}},
  FontSize->18],

Cell[StyleData["SlideTOCLink", "SlideShow"]],

Cell[StyleData["SlideTOCLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SlideTOC"],
  CellDingbat->"\[Bullet]",
  CellMargins->{{18, Inherited}, {Inherited, Inherited}},
  StyleMenuListing->None,
  FontFamily->"Helvetica"],

Cell[StyleData["SlideTOC", "Presentation"],
  CellMargins->{{25, 10}, {10, 5}},
  FontSize->18],

Cell[StyleData["SlideTOC", "SlideShow"],
  FontSize->14],

Cell[StyleData["SlideTOC", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 828}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 37, 0, 52, "Subtitle"],
Cell[1816, 55, 192, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[2033, 63, 42, 0, 69, "Section"],
Cell[2078, 65, 127, 3, 36, 31, 0, "StyleData", "All", "Working"],
Cell[2208, 70, 132, 3, 36, 36, 0, "StyleData", "All", \
"Presentation"],
Cell[2343, 75, 258, 7, 36, 33, 0, "StyleData", "All", "SlideShow"],
Cell[2604, 84, 104, 2, 36, 32, 0, "StyleData", "All", "Printout"],
Cell[2711, 88, 109, 2, 36, 37, 0, "StyleData", "All", \
"ColorPrintout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2857, 95, 35, 0, 69, "Section"],
Cell[2895, 97, 101, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[3021, 104, 398, 10, 36, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None],
Cell[3422, 116, 59, 1, 44, 43, 0, "StyleData", "Notebook", \
"Presentation"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3530, 123, 38, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[3593, 127, 1677, 40, 88, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}],
Cell[5273, 169, 92, 2, 70, 40, 0, "StyleData", "Title", \
"Presentation"],
Cell[5368, 173, 81, 2, 70, 36, 0, "StyleData", "Title", "Printout"],
Cell[5452, 177, 57, 1, 70, 41, 0, "StyleData", "Title", \
"ColorPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[5546, 183, 1581, 37, 49, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}, {"Subsubtitle", 0}}],
Cell[7130, 222, 96, 2, 70, 43, 0, "StyleData", "Subtitle", \
"Presentation"],
Cell[7229, 226, 89, 2, 70, 39, 0, "StyleData", "Subtitle", \
"Printout"],
Cell[7321, 230, 60, 1, 70, 44, 0, "StyleData", "Subtitle", \
"ColorPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[7418, 236, 1540, 37, 38, 30, 0, "StyleData", "Subsubtitle", \
"All",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}}],
Cell[8961, 275, 98, 2, 70, 46, 0, "StyleData", "Subsubtitle", \
"Presentation"],
Cell[9062, 279, 58, 1, 70, 42, 0, "StyleData", "Subsubtitle", \
"Printout"],
Cell[9123, 282, 63, 1, 70, 47, 0, "StyleData", "Subsubtitle", \
"ColorPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[9223, 288, 1618, 39, 62, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[10844, 329, 95, 2, 70, 42, 0, "StyleData", "Section", \
"Presentation"],
Cell[10942, 333, 88, 2, 70, 38, 0, "StyleData", "Section", \
"Printout"],
Cell[11033, 337, 59, 1, 70, 43, 0, "StyleData", "Section", \
"ColorPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[11129, 343, 1736, 42, 56, 29, 0, "StyleData", "Subsection", \
"All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[12868, 387, 98, 2, 86, 45, 0, "StyleData", "Subsection", \
"Presentation"],
Cell[12969, 391, 41, 0, 70, 41, 0, "StyleData", "Subsection", \
"Printout"],
Cell[13013, 393, 46, 0, 70, 46, 0, "StyleData", "Subsection", \
"ColorPrintout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13096, 398, 1716, 42, 64, 32, 0, "StyleData", "Subsubsection", \
"All",
  CounterIncrements->"Subsubsection"],
Cell[14815, 442, 100, 2, 69, 48, 0, "StyleData", "Subsubsection", \
"Presentation"],
Cell[14918, 446, 44, 0, 64, 44, 0, "StyleData", "Subsubsection", \
"Printout"],
Cell[14965, 448, 49, 0, 64, 49, 0, "StyleData", "Subsubsection", \
"ColorPrintout"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[15063, 454, 39, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[15127, 458, 1421, 34, 36, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[16551, 494, 90, 2, 50, 39, 0, "StyleData", "Text", \
"Presentation"],
Cell[16644, 498, 95, 3, 35, 35, 0, "StyleData", "Text", "Printout"],
Cell[16742, 503, 100, 3, 35, 40, 0, "StyleData", "Text", \
"ColorPrintout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16879, 511, 1364, 32, 35, 28, 0, "StyleData", "SmallText", "All",
  
  CounterIncrements->"SmallText"],
Cell[18246, 545, 96, 2, 70, 44, 0, "StyleData", "SmallText", \
"Presentation"],
Cell[18345, 549, 76, 2, 70, 40, 0, "StyleData", "SmallText", \
"Printout"],
Cell[18424, 553, 81, 2, 70, 45, 0, "StyleData", "SmallText", \
"ColorPrintout"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18554, 561, 36, 0, 69, "Section"],
Cell[18593, 563, 121, 3, 70, "Text"],
Cell[18717, 568, 92, 3, 70, 21, 0, "StyleData", "RM", "All",
  StyleMenuListing->None],
Cell[18812, 573, 69, 2, 70, 21, 0, "StyleData", "BF", "All",
  StyleMenuListing->None],
Cell[18884, 577, 70, 2, 70, 21, 0, "StyleData", "IT", "All",
  StyleMenuListing->None],
Cell[18957, 581, 115, 4, 70, 21, 0, "StyleData", "TR", "All",
  StyleMenuListing->None],
Cell[19075, 587, 116, 4, 70, 21, 0, "StyleData", "TI", "All",
  StyleMenuListing->None],
Cell[19194, 593, 114, 4, 70, 21, 0, "StyleData", "TB", "All",
  StyleMenuListing->None],
Cell[19311, 599, 116, 4, 70, 22, 0, "StyleData", "TBI", "All",
  StyleMenuListing->None],
Cell[19430, 605, 233, 6, 70, 21, 0, "StyleData", "MR", "All",
  StyleMenuListing->None],
Cell[19666, 613, 234, 6, 70, 21, 0, "StyleData", "MO", "All",
  StyleMenuListing->None],
Cell[19903, 621, 232, 6, 70, 21, 0, "StyleData", "MB", "All",
  StyleMenuListing->None],
Cell[20138, 629, 234, 6, 70, 22, 0, "StyleData", "MBO", "All",
  StyleMenuListing->None],
Cell[20375, 637, 119, 4, 70, 21, 0, "StyleData", "SR", "All",
  StyleMenuListing->None],
Cell[20497, 643, 120, 4, 70, 21, 0, "StyleData", "SO", "All",
  StyleMenuListing->None],
Cell[20620, 649, 118, 4, 70, 21, 0, "StyleData", "SB", "All",
  StyleMenuListing->None],
Cell[20741, 655, 120, 4, 70, 22, 0, "StyleData", "SBO", "All",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[20886, 663, 138, 5, 70, 23, 0, "StyleData", "SO10", "All",
  StyleMenuListing->None],
Cell[21027, 670, 149, 5, 70, 35, 0, "StyleData", "SO10", "Printout",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[21213, 680, 104, 2, 70, 24, 0, "StyleData", "Inert", "All",
  StyleMenuListing->None],
Cell[21320, 684, 90, 2, 70, 36, 0, "StyleData", "Inert", "Printout",
  StyleMenuListing->None]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[21459, 692, 42, 0, 39, "Section"],
Cell[21504, 694, 248, 5, 62, "Text"],

Cell[CellGroupData[{
Cell[21777, 703, 741, 20, 50, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[22521, 725, 132, 3, 69, 40, 0, "StyleData", "Input", \
"Presentation"],
Cell[22656, 730, 132, 3, 47, 36, 0, "StyleData", "Input", \
"Printout"],
Cell[22791, 735, 102, 2, 47, 41, 0, "StyleData", "Input", \
"ColorPrintout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22930, 742, 491, 14, 38, 30, 0, "StyleData", "InlineInput", \
"All",
  CounterIncrements->"Input"],
Cell[23424, 758, 96, 2, 70, 46, 0, "StyleData", "InlineInput", \
"Presentation"]
}, Closed]],

Cell[CellGroupData[{
Cell[23557, 765, 664, 17, 54, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[24224, 784, 133, 3, 70, 41, 0, "StyleData", "Output", \
"Presentation"],
Cell[24360, 789, 83, 2, 70, 37, 0, "StyleData", "Output", \
"Printout"],
Cell[24446, 793, 58, 1, 70, 42, 0, "StyleData", "Output", \
"ColorPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[24541, 799, 711, 19, 35, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[25255, 820, 93, 2, 70, 42, 0, "StyleData", "Message", \
"Presentation"],
Cell[25351, 824, 53, 1, 70, 38, 0, "StyleData", "Message", \
"Printout"],
Cell[25407, 827, 58, 1, 70, 43, 0, "StyleData", "Message", \
"ColorPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[25502, 833, 644, 17, 53, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[26149, 852, 133, 3, 70, 40, 0, "StyleData", "Print", \
"Presentation"],
Cell[26285, 857, 87, 2, 70, 36, 0, "StyleData", "Print", "Printout"],
Cell[26375, 861, 57, 1, 70, 41, 0, "StyleData", "Print", \
"ColorPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[26469, 867, 444, 12, 50, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics"],
Cell[26916, 881, 136, 3, 70, 43, 0, "StyleData", "Graphics", \
"Presentation"],
Cell[27055, 886, 85, 2, 70, 39, 0, "StyleData", "Graphics", \
"Printout"],
Cell[27143, 890, 60, 1, 70, 44, 0, "StyleData", "Graphics", \
"ColorPrintout"]
}, Closed]],

Cell[CellGroupData[{
Cell[27240, 896, 149, 4, 34, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[27392, 902, 60, 1, 70, 44, 0, "StyleData", "CellLabel", \
"Presentation"],
Cell[27455, 905, 82, 2, 70, 40, 0, "StyleData", "CellLabel", \
"Printout"],
Cell[27540, 909, 60, 1, 70, 45, 0, "StyleData", "CellLabel", \
"ColorPrintout"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[27649, 916, 35, 0, 69, "Section"],
Cell[27687, 918, 184, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[27896, 926, 302, 8, 70, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[28201, 936, 60, 1, 70, 44, 0, "StyleData", "Hyperlink", \
"Presentation"],
Cell[28264, 939, 57, 1, 70, 41, 0, "StyleData", "Hyperlink", \
"Condensed"],
Cell[28324, 942, 41, 0, 70, 41, 0, "StyleData", "Hyperlink", \
"SlideShow"],
Cell[28368, 944, 123, 3, 70, 40, 0, "StyleData", "Hyperlink", \
"Printout"]
}, Closed]],
Cell[28506, 950, 104, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[28635, 957, 293, 7, 70, 31, 0, "StyleData", "MainBookLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[28931, 966, 63, 1, 70, 47, 0, "StyleData", "MainBookLink", \
"Presentation"],
Cell[28997, 969, 60, 1, 70, 44, 0, "StyleData", "MainBookLink", \
"Condensed"],
Cell[29060, 972, 44, 0, 70, 44, 0, "StyleData", "MainBookLink", \
"SlideShow"],
Cell[29107, 974, 126, 3, 70, 43, 0, "StyleData", "MainBookLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[29270, 982, 314, 8, 70, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[29587, 992, 61, 1, 70, 45, 0, "StyleData", "AddOnsLink", \
"Presentation"],
Cell[29651, 995, 58, 1, 70, 42, 0, "StyleData", "AddOnsLink", \
"Condensed"],
Cell[29712, 998, 42, 0, 70, 42, 0, "StyleData", "AddOnsLink", \
"SlideShow"],
Cell[29757, 1000, 124, 3, 70, 41, 0, "StyleData", "AddOnsLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[29918, 1008, 318, 8, 70, 31, 0, "StyleData", "RefGuideLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[30239, 1018, 63, 1, 70, 47, 0, "StyleData", "RefGuideLink", \
"Presentation"],
Cell[30305, 1021, 60, 1, 70, 44, 0, "StyleData", "RefGuideLink", \
"Condensed"],
Cell[30368, 1024, 44, 0, 70, 44, 0, "StyleData", "RefGuideLink", \
"SlideShow"],
Cell[30415, 1026, 126, 3, 70, 43, 0, "StyleData", "RefGuideLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[30578, 1034, 297, 7, 70, 35, 0, "StyleData", "RefGuideLinkText", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[30878, 1043, 67, 1, 70, 51, 0, "StyleData", "RefGuideLinkText", \
"Presentation"],
Cell[30948, 1046, 64, 1, 70, 48, 0, "StyleData", "RefGuideLinkText", \
"Condensed"],
Cell[31015, 1049, 48, 0, 70, 48, 0, "StyleData", "RefGuideLinkText", \
"SlideShow"],
Cell[31066, 1051, 130, 3, 70, 47, 0, "StyleData", "RefGuideLinkText", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31233, 1059, 305, 7, 70, 37, 0, "StyleData", \
"GettingStartedLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[31541, 1068, 69, 1, 70, 53, 0, "StyleData", \
"GettingStartedLink", "Presentation"],
Cell[31613, 1071, 66, 1, 70, 50, 0, "StyleData", \
"GettingStartedLink", "Condensed"],
Cell[31682, 1074, 50, 0, 70, 50, 0, "StyleData", \
"GettingStartedLink", "SlideShow"],
Cell[31735, 1076, 132, 3, 70, 49, 0, "StyleData", \
"GettingStartedLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[31904, 1084, 287, 7, 70, 28, 0, "StyleData", "DemosLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[32194, 1093, 41, 0, 70, 41, 0, "StyleData", "DemosLink", \
"SlideShow"],
Cell[32238, 1095, 107, 2, 70, 40, 0, "StyleData", "DemosLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32382, 1102, 285, 7, 70, 27, 0, "StyleData", "TourLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[32670, 1111, 40, 0, 70, 40, 0, "StyleData", "TourLink", \
"SlideShow"],
Cell[32713, 1113, 106, 2, 70, 39, 0, "StyleData", "TourLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[32856, 1120, 309, 7, 70, 39, 0, "StyleData", \
"OtherInformationLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[33168, 1129, 71, 1, 70, 55, 0, "StyleData", \
"OtherInformationLink", "Presentation"],
Cell[33242, 1132, 68, 1, 70, 52, 0, "StyleData", \
"OtherInformationLink", "Condensed"],
Cell[33313, 1135, 52, 0, 70, 52, 0, "StyleData", \
"OtherInformationLink", "SlideShow"],
Cell[33368, 1137, 134, 3, 70, 51, 0, "StyleData", \
"OtherInformationLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[33539, 1145, 299, 7, 70, 34, 0, "StyleData", "MasterIndexLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[33841, 1154, 47, 0, 70, 47, 0, "StyleData", "MasterIndexLink", \
"SlideShow"],
Cell[33891, 1156, 113, 2, 70, 46, 0, "StyleData", "MasterIndexLink", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[34053, 1164, 33, 0, 39, "Section"],
Cell[34089, 1166, 121, 3, 46, "Text"],
Cell[34213, 1171, 226, 5, 36, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[34442, 1178, 304, 7, 36, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[34749, 1187, 400, 9, 36, 31, 0, "StyleData", "EvaluateCell", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[35152, 1198, 387, 9, 36, 31, 0, "StyleData", "CopyEvaluate", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[35542, 1209, 401, 9, 36, 35, 0, "StyleData", "CopyEvaluateCell", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Open  ]],

Cell[CellGroupData[{
Cell[35980, 1223, 36, 0, 69, "Section"],

Cell[CellGroupData[{
Cell[36041, 1227, 709, 21, 70, 41, 0, "StyleData", \
"SlideShowNavigationBar", "All",
  CounterIncrements->"SlideShowNavigationBar",
  StyleMenuListing->None],
Cell[36753, 1250, 199, 5, 70, 54, 0, "StyleData", \
"SlideShowNavigationBar", "SlideShow"],
Cell[36955, 1257, 126, 3, 70, 53, 0, "StyleData", \
"SlideShowNavigationBar", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[37118, 1265, 1702, 41, 70, 35, 0, "StyleData", \
"SlideShowSection", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  StyleMenuListing->None],
Cell[38823, 1308, 109, 2, 70, 51, 0, "StyleData", "SlideShowSection", \
"Presentation"],
Cell[38935, 1312, 98, 2, 70, 48, 0, "StyleData", "SlideShowSection", \
"SlideShow"],
Cell[39036, 1316, 122, 3, 70, 47, 0, "StyleData", "SlideShowSection", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[39195, 1324, 327, 10, 70, 33, 0, "StyleData", "SlideHyperlink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[39525, 1336, 102, 2, 70, 49, 0, "StyleData", "SlideHyperlink", \
"Presentation"],
Cell[39630, 1340, 46, 0, 70, 46, 0, "StyleData", "SlideHyperlink", \
"SlideShow"],
Cell[39679, 1342, 128, 3, 70, 45, 0, "StyleData", "SlideHyperlink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[39844, 1350, 341, 9, 70, 31, 0, "StyleData", "SlideTOCLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[40188, 1361, 99, 2, 70, 47, 0, "StyleData", "SlideTOCLink", \
"Presentation"],
Cell[40290, 1365, 44, 0, 70, 44, 0, "StyleData", "SlideTOCLink", \
"SlideShow"],
Cell[40337, 1367, 110, 2, 70, 43, 0, "StyleData", "SlideTOCLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[40484, 1374, 166, 4, 70, 27, 0, "StyleData", "SlideTOC", "All",
  StyleMenuListing->None],
Cell[40653, 1380, 95, 2, 70, 43, 0, "StyleData", "SlideTOC", \
"Presentation"],
Cell[40751, 1384, 56, 1, 70, 40, 0, "StyleData", "SlideTOC", \
"SlideShow"],
Cell[40810, 1387, 82, 2, 70, 39, 0, "StyleData", "SlideTOC", \
"Printout"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

